==> jc-1.4.0.tar.gz: gnu/java/util/DoubleEnumeration.h <==
// public class gnu.java.util.DoubleEnumeration

// class file dependencies
// @dep_class ca84f5a1410fdb92 gnu_java_util_DoubleEnumeration
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_DoubleEnumeration_H_
#define _JC_gnu_java_util_DoubleEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_gnu_java_util_DoubleEnumeration$sub_refs	_jc_gnu_java_util_DoubleEnumeration$sub_refs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$sub_nonrefs	_jc_gnu_java_util_DoubleEnumeration$sub_nonrefs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$refs	_jc_gnu_java_util_DoubleEnumeration$refs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$nonrefs	_jc_gnu_java_util_DoubleEnumeration$nonrefs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$object	_jc_gnu_java_util_DoubleEnumeration$object;

typedef const struct _jc_gnu_java_util_DoubleEnumeration$vmethods	_jc_gnu_java_util_DoubleEnumeration$vmethods;
typedef const struct _jc_gnu_java_util_DoubleEnumeration$vtable	_jc_gnu_java_util_DoubleEnumeration$vtable;
typedef const struct _jc_gnu_java_util_DoubleEnumeration$vtype	_jc_gnu_java_util_DoubleEnumeration$vtype;

// Constructors
extern void _jc_gnu_java_util_DoubleEnumeration$method$_init$1bb50fcb569606f2(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_gnu_java_util_DoubleEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_util_DoubleEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_DoubleEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_gnu_java_util_DoubleEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Virtual methods structure
struct _jc_gnu_java_util_DoubleEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *);
};

// Vtable
struct _jc_gnu_java_util_DoubleEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_DoubleEnumeration$vmethods	gnu_java_util_DoubleEnumeration;
};

// Vtype
struct _jc_gnu_java_util_DoubleEnumeration$vtype {
	_jc_type			type;
	_jc_gnu_java_util_DoubleEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_DoubleEnumeration$sub_refs {
	struct _jc_object	*e1;
	struct _jc_object	*e2;
};

// Reference instance fields (object)
struct _jc_gnu_java_util_DoubleEnumeration$refs {
    _jc_gnu_java_util_DoubleEnumeration$sub_refs	gnu_java_util_DoubleEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_DoubleEnumeration$sub_nonrefs {
	jboolean	hasMore;
	jboolean	hasChecked;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_DoubleEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_DoubleEnumeration$sub_nonrefs	gnu_java_util_DoubleEnumeration;
};

// Object instance structure
struct _jc_gnu_java_util_DoubleEnumeration$object {
	_jc_gnu_java_util_DoubleEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_DoubleEnumeration$vtype	*vtype;
	_jc_gnu_java_util_DoubleEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_DoubleEnumeration$vtype _jc_gnu_java_util_DoubleEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_DoubleEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_DoubleEnumeration$class_object;

#endif	/* _JC_gnu_java_util_DoubleEnumeration_H_ */

==> jc-1.4.6.tar.gz: gnu/java/util/DoubleEnumeration.h <==
// public class gnu.java.util.DoubleEnumeration

// class file dependencies
// @dep_class ca84f5a1410fdb92 gnu_java_util_DoubleEnumeration
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_util_DoubleEnumeration_H_
#define _JC_gnu_java_util_DoubleEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_gnu_java_util_DoubleEnumeration$sub_refs	_jc_gnu_java_util_DoubleEnumeration$sub_refs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$sub_nonrefs	_jc_gnu_java_util_DoubleEnumeration$sub_nonrefs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$refs	_jc_gnu_java_util_DoubleEnumeration$refs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$nonrefs	_jc_gnu_java_util_DoubleEnumeration$nonrefs;
typedef struct _jc_gnu_java_util_DoubleEnumeration$object	_jc_gnu_java_util_DoubleEnumeration$object;

typedef const struct _jc_gnu_java_util_DoubleEnumeration$vmethods	_jc_gnu_java_util_DoubleEnumeration$vmethods;
typedef const struct _jc_gnu_java_util_DoubleEnumeration$vtable	_jc_gnu_java_util_DoubleEnumeration$vtable;
typedef const struct _jc_gnu_java_util_DoubleEnumeration$vtype	_jc_gnu_java_util_DoubleEnumeration$vtype;

// Constructors
extern void _jc_gnu_java_util_DoubleEnumeration$method$_init$1bb50fcb569606f2(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_util_DoubleEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_util_DoubleEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_util_DoubleEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_gnu_java_util_DoubleEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Virtual methods structure
struct _jc_gnu_java_util_DoubleEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_gnu_java_util_DoubleEnumeration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_util_DoubleEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_util_DoubleEnumeration$vmethods	gnu_java_util_DoubleEnumeration;
};

// Vtype
struct _jc_gnu_java_util_DoubleEnumeration$vtype {
	_jc_type			type;
	_jc_gnu_java_util_DoubleEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_util_DoubleEnumeration$sub_refs {
	struct _jc_object	*e1;
	struct _jc_object	*e2;
};

// Reference instance fields (object)
struct _jc_gnu_java_util_DoubleEnumeration$refs {
    _jc_gnu_java_util_DoubleEnumeration$sub_refs	gnu_java_util_DoubleEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_util_DoubleEnumeration$sub_nonrefs {
	jboolean	hasMore;
	jboolean	hasChecked;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_util_DoubleEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_util_DoubleEnumeration$sub_nonrefs	gnu_java_util_DoubleEnumeration;
};

// Object instance structure
struct _jc_gnu_java_util_DoubleEnumeration$object {
	_jc_gnu_java_util_DoubleEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_util_DoubleEnumeration$vtype	*vtype;
	_jc_gnu_java_util_DoubleEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_util_DoubleEnumeration$vtype _jc_gnu_java_util_DoubleEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_util_DoubleEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_util_DoubleEnumeration$class_object;

#endif	/* _JC_gnu_java_util_DoubleEnumeration_H_ */
